# ======================================================
# ABOUT
# ===========================
'''
GunGame-Improvement (Python) by PitBull (pitbull0993)

CURRENT VERSION: 0.2

GG-Improvement improves the GunGame5 'gameplay' a little bit.

Current improvement:
    - When a user joins, the public will get a message how many wins and which rank the user has (using the snippet/addon by Sc0pE, hope you don't mind ^^)
    - Message on Level-Up through a exlpoded bomb
    - Message when bomb has been plant. A little cheer for the user ;-)
    - Message on Level-Up through a defused bomb
    - Users on Knife-Level are a bit faster than the others
    - Give the users more ammo than normal
    - Wrong-Weapon notification
'''
# ======================================================

# ======================================================
# IMPORTS
# ===========================
import es
import playerlib
import gungamelib
import ggweaponlib
import gamethread
# ======================================================

# ======================================================
# ADDON INFO
# ===========================
info = es.AddonInfo()
info.name     = 'GG-Improvement improves the GunGame-Gameplay a little bit'
info.version  = '0.2'
info.basename = 'gungame/custom_addons/gg_improvement'
info.author   = 'PitBull (pitbull0993)'

es.ServerVar('gg_improvement_ver', info.version).makepublic()
# ======================================================

# ======================================================
# GLOBALS
# ===========================
gg_improvement_joinmessage = gungamelib.getVariableValue('gg_improvement_joinmessage')
gg_improvement_knife = gungamelib.getVariableValue('gg_improvement_knife')
gg_improvement_knife_speed = gungamelib.getVariableValue('gg_improvement_knife_speed')
gg_improvement_bomb_planted = gungamelib.getVariableValue('gg_improvement_bomb_planted')
gg_improvement_bomb_exploded = gungamelib.getVariableValue('gg_improvement_bomb_exploded')
gg_improvement_bomb_defused = gungamelib.getVariableValue('gg_improvement_bomb_defused')
gg_improvement_ammo_more = gungamelib.getVariableValue('gg_improvement_ammo_more')
gg_improvement_wwnotify = gungamelib.getVariableValue('gg_improvement_wwnotify')

already_sent = []
# ======================================================
# LOAD/UNLOAD
# ===========================
def load():
    gg_improvement = gungamelib.registerAddon('gg_improvement')
    gg_improvement.setDisplayName('GG-IP')
    gg_improvement.loadTranslationFile()

def unload():
    gungamelib.unregisterAddon('gg_improvement')
    
# ======================================================

# ======================================================
# JOIN MESSAGE
# ===========================
def player_activate(event_var):
    userid = event_var['userid']
    gungamelib.msg('gg_improvement', userid, 'Advert', {'ver':info.version})
    if not gg_improvement_joinmessage:
        return
    
    gamethread.delayed(1.5, joinMessage, userid)

def joinMessage(userid):
    steamid = es.getplayersteamid(userid)
    if playerCheck(userid, steamid):
        wins = gungamelib.getWins(steamid)
        rank = gungamelib.getWinnerRank(steamid)
        if not wins:
            gungamelib.msg('gg_improvement', '#all', 'PlayerJoin_noRank', {'name':event_var['es_username'], 'wins':wins})
            return
        gungamelib.msg('gg_improvement', '#all', 'PlayerJoin', {'name':event_var['es_username'], 'wins':wins, 'rank':rank})

def playerCheck(userid, steamid):
    userid = int(userid)
    if userid in already_sent:
        return 0
    if steamid == 'BOT':
        return 0
    already_sent.append(userid)
    return 1

def player_disconnect(event_var):
    if not gg_improvement_joinmessage:
        return
    
    userid = int(event_var['userid'])
    if userid in already_sent:
        already_sent.remove(userid)

# ======================================================

# ======================================================
# KNIFE SPEED
# ===========================
def gg_levelup(event_var):
    # Check if Knife-Speed is active
    if not gg_improvement_knife:
        return
    # Check if Turbo-Mode is active, otherwise the person gets the speed on a lower level
    if not gungamelib.getVariable('gg_turbo'):
        return
    # If the new weapon is not equal to knife, stop here
    if not gungamelib.getPlayer(event_var['attacker']).getWeapon() == 'knife':
        return
    
    # Get the player out of the playerlib
    player = playerlib.getPlayer(event_var['attacker'])
    # Set the speed
    player.set("speed", gg_improvement_knife_speed)
    # Send a message
    gungamelib.msg('gg_improvement', '#all', 'KnifeSpeed_LevelUp', {'name':player['name'], 'speed':gg_improvement_knife_speed})

def player_spawn(event_var):
    # Check if Knife-Speed is active
    if not gg_improvement_knife:
        return

    # If the player's weapon is not knife, stop
    if not gungamelib.getPlayer(event_var['userid']).getWeapon() == 'knife':
        return

    # Get the player out of the playerlib
    player = playerlib.getPlayer(event_var['userid'])
    # Set the speed
    player.set("speed", gg_improvement_knife_speed)
    # Send a message
    gungamelib.msg('gg_improvement', '#all', 'KnifeSpeed_Spawn', {'name':player['name'], 'speed':gg_improvement_knife_speed})

# ======================================================

# ======================================================
# BOMB MESSAGES
# ===========================
def bomb_planted(event_var):
    if gg_improvement_bomb_planted:
        gungamelib.msg('gg_improvement', '#all', 'Bomb_Planted', {'name':event_var['es_username']})

def bomb_exploded(event_var):
    if gg_improvement_bomb_exploded:
        gungamelib.msg('gg_improvement', '#all', 'Bomb_Exploded', {'name':event_var['es_username']})

def bomb_defused(event_var):
    if gg_improvement_bomb_defused:
        gungamelib.msg('gg_improvement', '#all', 'Bomb_Defused', {'name':event_var['es_username']})

# ======================================================

# ======================================================
# AMMO
# ===========================
def item_pickup(event_var):
    # Is the item a weapon that can shoot at all?
    if not "#primary" in tags and "#secondary" in tags:
        # Stop
        return
    
    weapon = event_var['item']
    
    # Correct weapon?
    cWeapon = (weapon == gungamelib.getPlayer(event_var['userid'].getWeapon()))
    
    if gg_improvement_wwnotify:
        # If it's not the right weapon,
        if not cWeapon:
            # get the right weapon name
            r_weapon = str(gungamelib.getPlayer(event_var['userid']).getWeapon()).upper()
            # message the user
            gungamelib.msg('gg_improvement', event_var['userid'], 'Wrong_Weapon', {'w_weapon':weapon.upper(), 'r_weapon':r_weapon})
            # stop here (ammo_more is not needed if it's the wrong weapon)
            return
    
    # Should we set ammo higher?
    if not gg_improvement_ammo_more:
        # Stop
        return

    # Set the players ammo to the specified amount
    playerlib.getPlayer(event_var['userid']).set('ammo', [weapon, gg_improvement_ammo_more])

def player_death(event_var):
    # Should we set the ammo higher?
    if not gg_improvement_ammo_more:
        # Stop
        return
    
    # Is turbo-mode active?
    if gungamelib.getVariable('gg_turbo'):
        # Stop
        return
    
    tags = ggweaponlib.getWeaponInfo(weapon).get('tags')
    
    # Is the item a weapon that can shoot at all?
    if not "#primary" in tags and "#secondary" in tags:
        # Stop
        return
    
    # Set the ammo of the player
    playerlib.getPlayer(event_var['attacker']).set('ammo', [event_var['weapon'], gg_improvement_ammo_more])